@@ -130,9 +130,6 @@ class filesystem {
 								long *nodes);
 		static bool	getAvailableFileNodes(int fd, long *nodes);
 
-#if defined(HAVE_STATVFS) || \
-	defined(HAVE_NETBSD_STATVFS) || \
-	defined(HAVE_CYGWIN_STATFS)
 		// These methods return the file system id.
 		// (works on SCO OSR5, Solaris)
 		//
@@ -141,16 +138,6 @@ class filesystem {
 		long		getFileSystemId() const;
 		static bool	getFileSystemId(const char *path, long *id);
 		static bool	getFileSystemId(int fd, long *id);
-#else
-		// These methods return the file system id.
-		// (works on Linux, Net/Open/FreeBSD)
-		//
-		// The static methods return true on success and false on
-		// failure.
-		fsid_t		getFileSystemId() const;
-		static bool	getFileSystemId(const char *path, fsid_t *id);
-		static bool	getFileSystemId(int fd, fsid_t *id);
-#endif
 
 		// These methods return the maximum length of filenames.
 		// (works on Linux, SCO OSR5, Solaris)
@@ -271,7 +258,7 @@ class filesystem {
 
 		// This method returns a pointer to the statfs structure
 		// used internally.
-#if defined(HAVE_STATVFS) || defined(HAVE_NETBSD_STATVFS)
+#if defined(RUDIMENTS_HAVE_STATVFS) || defined(RUDIMENTS_HAVE_NETBSD_STATVFS)
 		struct statvfs	*getStatfs();
 #else
 		struct statfs	*getStatfs();
