@@ -3,8 +3,6 @@
 
 	private:
 		bool	close();
-#if defined(HAVE_LINUX_STATFS)
 		static	const char	*getFsTypeName(long type);
-#endif
 		void	filesystemClone(const filesystem &f);
 		filesystemprivate	*pvt;
