@@ -4,8 +4,8 @@
 	private:
 		void	write(const char *logentry);
 
-		loggerlist	logdestlist;
-
 		// FIXME: should be possible to copy a logger
 			logger(const logger &l);
 		logger	&operator=(const logger &l);
+
+		loggerprivate	*pvt;
