@@ -5,6 +5,3 @@
 #include <rudiments/private/rudimentsinlines.h>
 
 #include <termios.h>
-
-// FIXME: can this be moved into serialportprofile.C
-#include <unistd.h>
