@@ -2,9 +2,7 @@
 // See the COPYING file for more information.
 
 	private:
-		struct	sigaction	handlerstruct;
-			int		signalnumber;
-
 		// FIXME: should be possible to copy a signalhandler
 				signalhandler(const signalhandler &s);
 		signalhandler	&operator=(const signalhandler &s);
+		signalhandlerprivate	*pvt;
