@@ -2,23 +2,6 @@
 // See the COPYING file for more information.
 
 	private:
-		bool		cascade;
-
-		xmldomnodetype	type;
-		char		*nodename;
-		char		*nodevalue;
-		xmldomnode	*parent;
-		xmldomnode	*next;
-		xmldomnode	*previous;
-		int		childcount;
-		xmldomnode	*firstchild;
-		xmldomnode	*lastchild;
-		int		attributecount;
-		xmldomnode	*firstattribute;
-		xmldomnode	*lastattribute;
-		xmldomnode	*nullnode;
-		bool		isnullnode;
-
 		void		init(xmldomnode *nullnode);
 		xmldomnode	*getNode(xmldomnode *first,
 					int position, const char *name,
@@ -36,3 +19,5 @@
 
 				xmldomnode(const xmldomnode &x);
 		xmldomnode	&operator=(const xmldomnode &x);
+
+		xmldomnodeprivate	*pvt;
