@@ -19,16 +19,9 @@
 			void	parseTextFailed();
 			char	skipWhitespace(char current);
 			char	getCharacter();
+			bool	mapFile();
 
-			const char	*string;
-			const char	*ptr;
-			file		fl;
-			#ifdef HAVE_MMAP
-			memorymap	mm;
-			#endif
-			long		line;
-			bool		allowtrailingtext;
-			stringbuffer	err;
+				xmlsax(const xmlsax &x);
+			xmlsax	&operator=(const xmlsax &x);
 
-			xmlsax(const xmlsax &x);
-		xmlsax	&operator=(const xmlsax &x);
+			xmlsaxprivate	*pvt;
